@@ -12,7 +12,7 @@ from pysmt.smtlib.parser import Tokenizer
 from pysmt.shortcuts import NotEquals
 
 
-class AbstractSMTLibSolverProxy(object):
+class AbstractSMTLibSolverProxy:
     def write(self, smt):
         raise NotImplementedError
 
@@ -23,34 +23,35 @@ class AbstractSMTLibSolverProxy(object):
         pass
 
     def reset(self):
-        self.write('(reset)\n')
+        self.write("(reset)\n")
 
     def readuntil(self, s):
-        buf = b''
+        buf = b""
         s = s.encode()
         while s not in buf:
             buf += self.read(1)
         return buf
 
     def readline(self):
-        return self.readuntil('\n')
+        return self.readuntil("\n")
 
     def writeline(self, l):
-        return self.write(l + '\n')
+        return self.write(l + "\n")
 
     def read_sat(self):
-        return self.readline().strip().decode('utf-8')
+        return self.readline().strip().decode("utf-8")
 
     def read_model(self):
-        read_model = self.readuntil('\n)\n').strip().decode('utf-8')
+        read_model = self.readuntil("\n)\n").strip().decode("utf-8")
         return read_model
 
     def create_process(self):
         raise NotImplementedError
 
+
 class PopenSolverProxy(AbstractSMTLibSolverProxy):
     def __init__(self, p):
-        super(PopenSolverProxy, self).__init__()
+        super().__init__()
         self.p = p
         self.constraints = []
 
@@ -75,11 +76,11 @@ class PopenSolverProxy(AbstractSMTLibSolverProxy):
 
 class SMTLibSolverBackend(BackendSMTLibBase):
     def __init__(self, *args, **kwargs):
-        kwargs['solver_required'] = True
-        self.smt_script_log_dir = kwargs.pop('smt_script_log_dir', None)
-        super(SMTLibSolverBackend, self).__init__(*args, **kwargs)
+        kwargs["solver_required"] = True
+        self.smt_script_log_dir = kwargs.pop("smt_script_log_dir", None)
+        super().__init__(*args, **kwargs)
 
-    def solver(self, timeout=None, max_memory=None): #pylint:disable=no-self-use,unused-argument
+    def solver(self, timeout=None, max_memory=None):  # pylint:disable=no-self-use,unused-argument
         """
         This function should return an instance of whatever object handles
         solving for this backend. For example, in Z3, this would be z3.Solver().
@@ -91,7 +92,8 @@ class SMTLibSolverBackend(BackendSMTLibBase):
         if not substituted.is_constant():
             raise BackendError(
                 "CVC4 backend currently only supports requests for symbols directly! This is a weird one that doesn't "
-                "turn constant after substitution??")
+                "turn constant after substitution??"
+            )
 
         return substituted.constant_value()
 
@@ -109,7 +111,10 @@ class SMTLibSolverBackend(BackendSMTLibBase):
         return False
 
     def _batch_eval(self, exprs, n, extra_constraints=(), solver=None, model_callback=None):
-        return [self._eval(e, n, extra_constraints=extra_constraints, solver=solver, model_callback=model_callback) for e in exprs]
+        return [
+            self._eval(e, n, extra_constraints=extra_constraints, solver=solver, model_callback=model_callback)
+            for e in exprs
+        ]
 
     def _add(self, s, c, track=False):
         s.add_constraints(c, track=track)
@@ -119,17 +124,17 @@ class SMTLibSolverBackend(BackendSMTLibBase):
         smt_script = self._get_satisfiability_smt_script(constraints=csts, variables=vars)
 
         if self.smt_script_log_dir is not None:
-            fname = 'check-sat_{}.smt2'.format(hashlib.md5(smt_script.encode()).hexdigest())
+            fname = f"check-sat_{hashlib.md5(smt_script.encode()).hexdigest()}.smt2"
 
-            with open(os.path.join(self.smt_script_log_dir, fname), 'wb') as f:
+            with open(os.path.join(self.smt_script_log_dir, fname), "wb") as f:
                 f.write(smt_script.encode())
 
         solver.reset()
         solver.write(smt_script)
 
         sat = solver.read_sat().upper()
-        if sat not in {'SAT', 'UNSAT', 'UNKNOWN'}:
-            raise ValueError("Solver error, don't understand (check-sat) response: {}".format(repr(sat)))
+        if sat not in {"SAT", "UNSAT", "UNKNOWN"}:
+            raise ValueError(f"Solver error, don't understand (check-sat) response: {repr(sat)}")
         return sat.upper()
 
     def _check_satisfiability(self, extra_constraints=(), solver=None, model_callback=None, extra_variables=()):
@@ -141,21 +146,21 @@ class SMTLibSolverBackend(BackendSMTLibBase):
         # solver is done, terminate process
         solver.terminate()
 
-        return satness == 'SAT'
+        return satness == "SAT"
 
     def _get_model(self, solver=None, extra_constraints=(), extra_variables=()):
         vars, csts = self._get_all_vars_and_constraints(solver=solver, e_c=extra_constraints, e_v=extra_variables)
         smt_script = self._get_full_model_smt_script(constraints=csts, variables=vars)
         if self.smt_script_log_dir is not None:
-            fname = 'get-model_{}.smt2'.format(hashlib.md5(smt_script.encode()).hexdigest())
-            with open(os.path.join(self.smt_script_log_dir, fname), 'wb') as f:
+            fname = f"get-model_{hashlib.md5(smt_script.encode()).hexdigest()}.smt2"
+            with open(os.path.join(self.smt_script_log_dir, fname), "wb") as f:
                 f.write(smt_script.encode())
 
         solver.reset()
         solver.write(smt_script)
 
         sat = solver.read_sat()
-        if sat == 'sat':
+        if sat == "sat":
             model_string = solver.read_model()
             tokens = Tokenizer(StringIO(model_string), interactive=True)
             ass_list = SMTParser(tokens).consume_assignment_list()
@@ -176,7 +181,7 @@ class SMTLibSolverBackend(BackendSMTLibBase):
         results = []
         while len(results) < n:
             sat, model, ass_list = self._get_model(solver=solver, extra_constraints=e_c, extra_variables=expr_vars)
-            if sat != 'sat':
+            if sat != "sat":
                 break
 
             val = self._get_primitive_for_expr(model, expr)
@@ -207,8 +212,11 @@ class SMTLibSolverBackend(BackendSMTLibBase):
             raise BackendError("%s requires a solver for evaluation" % self.__class__.__name__)
 
         results = self._eval(
-            self.convert(expr), n, extra_constraints=self.convert_list(extra_constraints),
-            solver=solver, model_callback=model_callback
+            self.convert(expr),
+            n,
+            extra_constraints=self.convert_list(extra_constraints),
+            solver=solver,
+            model_callback=model_callback,
         )
 
         results = list(results)
@@ -217,13 +225,14 @@ class SMTLibSolverBackend(BackendSMTLibBase):
 
         size = expr.length
         for i in range(len(results)):
-            results[i] &= (1 << size) - 1 # convert it back to unsigned
+            results[i] &= (1 << size) - 1  # convert it back to unsigned
 
         # solver is done, terminate process
         solver.terminate()
 
         return results
 
+
 from . import cvc4_popen
 from . import z3_popen
 from . import abc_popen
